@@ -87,7 +87,7 @@ class WordpressAPI(object):
 
 class IdenticaAPI(Api):
 
-    _API_REALM = 'StatusNet API'
+    _API_REALM = 'Identi.ca API'
 
     def PostUpdate(self, text):
         import simplejson
